@@ -26,7 +26,6 @@ const TERMINAL_PROLOGUE: &str = "static USB_VIDEO_TERMINALS: phf::Map<u16, Video
 
 trait CgEntry<T> {
     fn id(&self) -> T;
-    fn name(&self) -> &str;
 }
 
 struct CgVendor {
@@ -59,10 +58,6 @@ impl<T: Copy, C: CgEntry<T>> CgEntry<T> for CgParentType<T, C> {
     fn id(&self) -> T {
         self.id
     }
-
-    fn name(&self) -> &str {
-        &self.name
-    }
 }
 
 struct CgType<T> {
@@ -74,10 +69,6 @@ impl<T: Copy> CgEntry<T> for CgType<T> {
     fn id(&self) -> T {
         self.id
     }
-
-    fn name(&self) -> &str {
-        &self.name
-    }
 }
 
 type CgInterface = CgType<u8>;
@@ -508,6 +499,7 @@ fn main() {
     // Parser state machine starts with vendors (first in file)
     let mut parser_state: ParserState = ParserState::Vendors(Map::<u16>::new(), None, 0u16);
 
+    #[allow(clippy::lines_filter_map_ok)]
     for line in input.lines().flatten() {
         // Check for a state change based on the header comments
         if let Some(next_state) = parser_state.next_from_header(&line, &mut output) {
